@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2008-2020)
+#   Copyright (C) Dr. Heinz-Josef Claes (2008-2009)
 #                 hjclaes@web.de
 #   
 #   This program is free software: you can redistribute it and/or modify
@@ -19,6 +19,9 @@
 #
 
 
+my $VERSION = '$Id: storeBackupSearch.pl 341 2008-07-31 13:13:17Z hjc $ ';
+push @VERSION, $VERSION;
+my ($VERSIONpName, $VERSIONsvnID) = $VERSION =~ /Id:\s+(\S+)\s+(\d+)/;
 $main::STOREBACKUPVERSION = undef;
 
 
@@ -99,9 +102,6 @@ require 'storeBackupLib.pl';
 
 my $checkSumFile = '.md5CheckSums';
 
-my $tmpdir = '/tmp';              # default value
-$tmpdir = $ENV{'TMPDIR'} if defined $ENV{'TMPDIR'};
-
 =head1 NAME
 
 storeBackupSearch.pl - locates different versions of a file saved with storeBackup.pl.
@@ -110,9 +110,9 @@ storeBackupSearch.pl - locates different versions of a file saved with storeBack
 
 	storeBackupSearch.pl -g configFile
 
-	storeBackupSearch.pl -b backupDirDir [-f configFile]
+	storeBackupSearch.pl [-f configFile] [-b backupDirDir]
 	      [-s rule]  [--absPath] [-w file] [--parJobs number]
-	      [-d level] [--once] [--print] [-T tmpdir] [backupRoot . . .]
+	      [-d level] [--once] [--print] [backupRoot . . .]
 
 =head1 DESCRIPTION
 
@@ -135,7 +135,7 @@ You need some basic understanding of linux and perl to use it.
     configuration file (instead of or
     additionally to parameters)
 
-=item B<--backupDir> B<-b>
+=item B<--backupDir> F<backupDirDir>, B<-b> F<backupDirDir>
 
 		    top level directory of all backups
 
@@ -164,10 +164,6 @@ You need some basic understanding of linux and perl to use it.
 
     show every file found only once (depending on md5 sum)
 
-=item B<--tmpdir>, B<-T>
-
-    directory for temporary files, default is </tmp>
-
 =item backupRoot
 
     Root directories of backups where to search relative
@@ -178,15 +174,17 @@ You need some basic understanding of linux and perl to use it.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2020 by Heinz-Josef Claes (see README).
+Copyright (c) 2008-2009 by Heinz-Josef Claes (see README).
 Published under the GNU General Public License v3 or any later version
 
 =cut
 
-my $Help = &::getPod2Text($0);
+my $Help = join('', grep(!/^\s*$/, `pod2text $0`));
+$Help = "cannot find pod2text, see documentation for details\n"
+    unless $Help;
 
 my $templateConfigFile = <<EOC;
-# configuration file for storeBackupSearch.pl, version $main::STOREBACKUPVERSION
+# configuration file for storeBackup.pl
 
 # You can set a value specified with '-cf_key' (eg. logFiles) and
 # continue at the next lines which have to begin with a white space:
@@ -227,12 +225,9 @@ my $templateConfigFile = <<EOC;
 # root directory of backup relative to backupDir directory
 ;backupRoot=
 
-# directory for temporary file, default is /tmp
-;tmpDir=
-
 # write result with absolute path names
 # default is 'no', possible values are 'yes' and 'no'
-;absPath=
+;absPath
 
 # write search result also to file
 ;writeToFile=
@@ -250,12 +245,12 @@ EOC
     ;
 
 
-&printVersion(\@ARGV, '-V', '--version');
+&printVersions(\@ARGV, '-V');
 
 my $CheckPar =
     CheckParam->new('-configFile' => '-f',
 		    '-allowLists' => 'yes',
-#		    '-listMapping' => 'backupRoot',
+		    '-listMapping' => 'backupRoot',
 		    '-list' => [Option->new('-name' => 'configFile',
 					    '-cl_option' => '-f',
 					    '-cl_alias' => '--configFile',
@@ -306,13 +301,7 @@ my $CheckPar =
 					    '-cf_noOptSet' => ['yes', 'no']),
 				Option->new('-name' => 'print',
 					    '-cl_option' => '--print'),
-				Option->new('-name' => 'tmpdir',
-					    '-cl_option' => '-T',
-					    '-cl_alias' => '--tmpdir',
-					    '-cf_key' => 'tmpDir',
-					    '-default' => $tmpdir),
 				Option->new('-name' => 'backupRoot',
-					    '-cl_option' => '--backupRoot',
 					    '-cf_key' => 'backupRoot',
 					    '-param' => 'yes'),
 # hidden options
@@ -332,7 +321,6 @@ $CheckPar->check('-argv' => \@ARGV,
                  '-help' => $Help
                  );
 
-
 # Auswertung der Parameter
 my $configFile = $CheckPar->getOptWithPar('configFile');
 my $generateConfigFile = $CheckPar->getOptWithPar('generate');
@@ -344,8 +332,7 @@ my $writeAbsPath = $CheckPar->getOptWithoutPar('writeAbsPath');
 my $parJobs = $CheckPar->getOptWithPar('parJobs');
 my $debug = $CheckPar->getOptWithPar('debug');
 my $once = $CheckPar->getOptWithoutPar('once');
-$tmpdir = $CheckPar->getOptWithPar('tmpdir');
-my (@backupRoot) = ($CheckPar->getOptWithPar('backupRoot'));
+my (@backupRoot) = $CheckPar->getListPar();
 
 my $printAll = $CheckPar->getOptWithoutPar('printAll');
 $print = 1 if $printAll;
@@ -397,13 +384,11 @@ if ($print)
 }
 
 my $prLog = printLog->new('-kind' => ['I:INFO', 'W:WARNING', 'E:ERROR',
-				      'S:STATISTIC', 'D:DEBUG', 'V:VERSION'],
-			  '-tmpdir' => $tmpdir);
-$main::__prLog = $prLog;   # used in rules
-$prLog->fork($req);
+				      'S:STATISTIC', 'D:DEBUG', 'V:VERSION']);
 
 $prLog->print('-kind' => 'V',
-	      '-str' => ["storeBackupSearch.pl, $main::STOREBACKUPVERSION"]);
+	      '-str' => ["$VERSIONpName, $main::STOREBACKUPVERSION, " .
+			 "build $VERSIONsvnID"]);
 
 $prLog->print('-kind' => 'E',
 	      '-str' => ["missing parameters backupDir and searchRule\n$Help"],
@@ -468,7 +453,7 @@ if (@backupRoot)
 		      '-str' => ["directory <$d> is not a subdirectory " .
 				 "of backupDir <$backupDir>"],
 		      '-exit' => 1)
-	    unless &::isSubDir($backupDir, $d);
+	    unless $d =~ /\A$backupDir/;
 
 	# now get all dirs from @$allStbuDirs below $d
 	my $a;
@@ -526,10 +511,7 @@ foreach $dirToSearch (@dirsToSearch)
 				 "<$dirToSearch> ... skipping"]);
 	next;
     }
-#    if (-f "$dirToSearch/$checkSumFile.notFinished")
-    unless (&::checkIfBackupWasFinished('-backupDir' => "$dirToSearch",
-					    '-prLog' => $prLog,
-					'-count' => 40))
+    if (-f "$dirToSearch/$checkSumFile.notFinished")
     {
 	$prLog->print('-kind' => 'E',
 		      '-str' => ["backup <$dirToSearch> not finished" .
@@ -546,11 +528,9 @@ foreach $dirToSearch (@dirsToSearch)
 
     my $rcsf =
 	readCheckSumFile->new('-checkSumFile' => "$dirToSearch/$checkSumFile",
-			      '-prLog' => $prLog,
-			      '-tmpdir' => $tmpdir);
-#    my $meta = $rcsf->getMetaValField();
-#    my $postfix = ($$meta{'postfix'})->[0];    # postfix for compression
-    my $postfix = $rcsf->getInfoWithPar('postfix');
+			      '-prLog' => $prLog);
+    my $meta = $rcsf->getMetaValField();
+    my $postfix = ($$meta{'postfix'})->[0];    # postfix for compression
 
     my $jobToDo = 1;
     my $parForkToDo = 1;
@@ -620,7 +600,7 @@ foreach $dirToSearch (@dirsToSearch)
 		push @lineBuffer, $l;
 	    }
 	    $jobToDo = @lineBuffer;
-	    my $tmpName = &::uniqFileName("/$tmpdir/storeBackupSearch-");
+	    my $tmpName = &::uniqFileName("/tmp/storeBackupSearch-");
 
 	    if ($jobToDo)
 	    {
