@@ -1,7 +1,7 @@
 # -*- perl -*-
 
 #
-#   Copyright (C) Heinz-Josef Claes (2001-2020)
+#   Copyright (C) Heinz-Josef Claes (2001-2009)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -20,174 +20,16 @@
 
 
 
-use Digest::MD5 qw(md5_hex);
+push @VERSION, '$Id: fileDir.pl 357 2009-05-02 15:05:33Z hjc $ ';
+
 use Fcntl qw(O_RDWR O_CREAT);
-use Fcntl ':mode';
 use POSIX;
-use Cwd 'abs_path';
 
 require 'prLog.pl';
 require 'forkProc.pl';
 
 use strict;
 
-
-# copies a file
-# returns:
-#          1: ok
-#          0: error
-############################################################
-sub copyFile
-{
-    my $source = shift;
-    my $target = shift;
-    my $prLog = shift;
-
-    local *SOURCE;
-    local *TARGET;
-    unless (sysopen(SOURCE, $source, O_RDONLY))
-    {
-	$prLog->print('-kind' => 'E',
-		      '-str' => ["cannot open <$source> for reading"]);
-	return 0;
-    }
-    unless (sysopen(TARGET, $target, O_CREAT | O_WRONLY))
-    {
-	$prLog->print('-kind' => 'E',
-		      '-str' => ["cannot create <$target> for writing"]);
-	return 0;
-    }
-    my $buffer;
-    while (sysread(SOURCE, $buffer, 10*1024**2))
-    {
-	unless (syswrite(TARGET, $buffer))
-	{
-	    $prLog->print('-kind' => 'E',
-			  '-str' => [$!]);
-	    return 0;
-	}
-    }
-
-    close(TARGET);
-    close(SOURCE);
-
-    return 1;
-}
-
-############################################################
-sub copySymLink
-{
-    my $source = shift;    # symlink source
-    my $target = shift;    # symlink target
-
-    my $l = readlink $source;
-    unless ($l)
-    {
-	return 0;
-    }
-    unless (symlink $l, $target)
-    {
-	return 0;
-    }
-    else
-    {
-	return 1;
-    }
-}
-
-
-############################################################
-# use cp_a to copy a directory
-# $ignoreError = 1 -> ignore error
-# $ignoreError = 0 -> stop at error
-sub copyDir
-{
-    my ($from, $to, $tmp, $prLog, $ignoreError) = (@_);
-
-    my $cp = forkProc->new('-exec' => 'cp',
-			   '-param' =>
-			   ['-r', "$from", "$to"],
-			   '-outRandom' => $tmp,
-			   '-prLog' => $prLog);
-    $cp->wait();
-    my $out = $cp->getSTDOUT();
-    if (@$out)
-    {
-	$prLog->print('-kind' => 'W',
-		      '-str' =>
-		      ["copying of <$from> to <$to> reported:",
-		       @$out]);
-    }
-    $out = $cp->getSTDERR();
-    if (@$out)
-    {
-	$prLog->print('-kind' => 'E',
-		      '-str' =>
-		      ["copying (with 'cp -r') of <$from> to <$to> reported:",
-		       @$out]);
-	exit 1 unless $ignoreError;
-    }
-}
-
-
-############################################################
-# use mv to move a directory
-sub mvComm
-{
-    my ($from, $to, $tmp, $prLog) = (@_);
-
-    my $cp = forkProc->new('-exec' => 'mv',
-			   '-param' =>
-			   ["$from", "$to"],
-			   '-outRandom' => $tmp,
-			   '-prLog' => $prLog);
-    $cp->wait();
-    my $out = $cp->getSTDOUT();
-    if (@$out)
-    {
-	$prLog->print('-kind' => 'W',
-		      '-str' =>
-		      ["moving of <$from> to <$to> reported:",
-		       @$out]);
-    }
-    $out = $cp->getSTDERR();
-    if (@$out)
-    {
-	$prLog->print('-kind' => 'E',
-		      '-str' =>
-		      ["moving of <$from> to <$to> reported:",
-		       @$out],
-		      '-exit' => 1);
-    }
-}
-
-
-
-############################################################
-# &::readDirStbu($dir, __FILE__, __LINE__, $prLog);
-sub readDirStbu
-{
-    my ($dir, $file, $line, $pattern, $prLog) = (@_);
-
-    local *DIR;
-    opendir(DIR, "$dir") or
-	$prLog->print('-kind' => 'E',
-		      '-str' =>
-		      ["cannot opendir <$dir>, exiting"],
-		      '-add' => [$file, $line],
-		      '-exit' => 1);
-    my (@dirs, $entry);
-    while ($entry = readdir DIR)
-    {
-	next unless $entry =~ /$pattern/;
-	push @dirs, $entry;
-    }
-    closedir(DIR);
-
-    return (sort @dirs);
-}
-
-
 # checks if a file is a symlink and deletes it if wanted
 # return values (if not exiting):
 #               0: no symlink
@@ -199,7 +41,7 @@ sub checkDelSymLink
     my $prLog = shift;
     my $delExit = shift;    # set bits:
                             #  bit 0:  0 = do not delete
-                            #          1 = delete symlink
+                            #          1 = delete synlink
                             #              if not possible, exit
                             #  bit 1:  0 = do not exit (if exists)
                             #          1 = exit
@@ -234,38 +76,91 @@ sub splitFileDir
     my $name = shift;
 
     return (undef, undef) unless $name;
-    return ('.', $name) unless ($name =~/\//);    # simple file name only
+    return ('.', $name) unless ($name =~/\//);    # nur einfacher Dateiname
 
     my ($dir, $file) = $name =~ /^(.*)\/(.*)$/s;
-    $dir = '/' if ($dir eq '');                   # if eg. /filename
+    $dir = '/' if ($dir eq '');                   # gilt, falls z.B. /filename
     return ($dir, $file);
 }
 
 
 ############################################################
-# Parameter may be directory or file
+# Parameter kann directory oder Datei sein
 %main::absolutePathCache = ();
 @main::absolutePathCache = ();
 sub absolutePath
 {
     my $dir = shift;
-    my $dirSave = $dir;
 
-    return undef unless $dir and -e $dir;
+    return undef unless $dir;
 
-    # First look up in the hash table if that's already calculated
+    # Erst im Hash nachsehen, ob das schon ermittelt wurde
     return $main::absolutePathCache{$dir}
         if exists $main::absolutePathCache{$dir};
+    my $dirSave = $dir;
+
+    # Falls Datei selbst ein symlink ist, solange folgen, bis aufgelst
+    my $file = '';
+
+
+    $dir = $ENV{'PWD'} . "/$dir" unless ($dir =~ /^\//); # relativer Pfad
+
+    if (-e $dir)
+    {
+	$file = $dir;
+	while (-l $file)
+	{
+	    my $link = readlink($file);
+
+	    if (substr($link, 0, 1) ne "/")
+	    {
+		$file =~ s/[^\/]+$/$link/;
+	    }
+	    else
+	    {
+		$file = $link;
+	    }
+	}
+
+	($dir, $file) = &splitFileDir($file);
+	$file = "/$file";
+    }
+
+    my $ret = (-e "$dir$file") ? "$dir$file" : undef;
+    $ret =~ s/\/\//\//g;       # // -> /
+    $ret =~ s/\/\.\//\//g;     # /./ -> /
+    $ret =~ s/\A(.+)\/\Z/$1/;  # remove trailing /
+    $ret =~ s/\A\.\///;        # ./xxx -> xxx
+    $ret =~ s/\/\.\Z//;        # xxx/. -> xxx
+
+    # eliminate /../
+    my (@ret) = split(/\//, $ret);
+    if (@ret)
+    {
+	my (@rev) = reverse(@ret);
+	(@ret) = ();
+	my ($i, $j);
+	for ($i = $j = 0 ; $i < @rev ; $i++, $j++)
+	{
+	    if ($rev[$i] eq '..')
+	    {
+		$j++;
+	    }
+	    else
+	    {
+		push @ret, $rev[$j] if ($j < @rev);
+	    }
+	}
+	$ret = join('/', reverse @ret);
+    }
 
     if (@main::absolutePathCache > 100)
     {
 	my $del = shift @main::absolutePathCache;   # delete oldest
 	delete $main::absolutePathCache{$del};
     }
-    my $ret = abs_path($dir);
     push @main::absolutePathCache, $ret;
-    $main::absolutePathCache{$dirSave} = $ret;
-    return $ret;
+    return $main::absolutePathCache{$dirSave} = $ret;
 }
 
 
@@ -309,7 +204,7 @@ sub relPath
 ############################################################
 sub uniqFileName
 {
-    my $prefix = shift;                 # eg. '/tmp/test-'
+    my $prefix = shift;                 # z.B. '/tmp/test-'
 
     my $suffix;
     do
@@ -323,7 +218,7 @@ sub uniqFileName
 
 
 ############################################################
-# tests if subDir is a sub directory of dir
+# testet, ob subDir ein Unterverzeichnis von dir ist
 sub isSubDir
 {
     my $dir = shift;
@@ -370,21 +265,17 @@ sub makeFilePath
     my $prLog = shift;
 
     $path =~ m#\A(.*)/.*\Z#s;
-    &makeDirPath($1, $prLog);
+    &makeDirPath($1);
 }
 
 
 ############################################################
 # like `mkdir -p`, all permissions set to 0700
-# success: returns 1
-# no success: returns 0
 sub makeDirPath
 {
     my $path = shift;
     my $prLog = shift;
 
-    return unless $path;
-
     my @p;
     return if -e $path;
 
@@ -392,14 +283,12 @@ sub makeDirPath
 
     &makeDirPath($p1, $prLog);
 
-    unless (mkdir $path, 0700)
-    {
-	return if -e $path;
-	$prLog->print('-kind' => 'E',
-		      '-str' => ["cannot create directory <$path>"]);
-	return 0;
-    }
-    return 1;
+    $prLog->print('-kind' => 'E',
+		  '-str' => ["cannot create directory <$path>"],
+		  '-exit' => 1)
+	unless mkdir $path, 0700;
+
+    return;
 }
 
 
@@ -449,7 +338,7 @@ sub checkLockFile
     local *FILE;
     if (-f $lockFile)
     {
-	open(FILE, '<', $lockFile) or
+	open(FILE, "< $lockFile") or
 	    $prLog->print('-kind' => 'E',
 			  '-str' => ["cannot read lock file <$lockFile>"],
 			  '-exit' => 1);
@@ -474,19 +363,13 @@ sub checkLockFile
 			  '-str' => ["removing old lock file of process <$pid>"]
 			  );
 	}
-	unless (unlink $lockFile)
-	{
-	    $prLog->print('-kind' => 'E',
-			  '-str' => ["cannot remove lock file <$lockFile"],
-			  '-exit' => 1);
-	}
     }
 
     $prLog->print('-kind' => 'I',
 		  '-str' => ["creating lock file <$lockFile>"]);
 
     &::checkDelSymLink($lockFile, $prLog, 0x01);
-    open(FILE, '>', $lockFile) or
+    open(FILE, "> $lockFile") or
 	$prLog->print('-kind' => 'E',
 		      '-str' => ["cannot create lock file <$lockFile>"],
 		      '-exit' => 1);
@@ -504,9 +387,6 @@ sub calcMD5
     local *FROM;
     unless (sysopen(FROM, $filename, O_RDONLY))
     {
-	$prLog->print('-kind' => 'E',
-		      '-str' => ["cannot open <$filename> in calcMD5"])
-	    if $prLog;
 	return undef;
     }
     my $md5 = Digest::MD5->new();
@@ -520,266 +400,6 @@ sub calcMD5
 }
 
 
-############################################################
-sub readSymLinkCalcMd5
-{
-    my $filename = shift;
-    my $prLog = shift;
-
-    my $l = readlink $filename;
-    unless ($l)
-    {
-	$prLog->print('-kind' => 'E',
-		      '-str' => ["cannot read symlink value <$filename>"]);
-	return undef;
-    }
-    my $md5 = Digest::MD5->new();
-    $md5->add($l);
-    return $md5->hexdigest();
-}
-
-############################################################
-sub createArchiveFromFile
-{
-    my $filename = shift;   # relative path
-    my $sourceDir = shift;
-    my $backupDir = shift;
-    my $archiver = shift;
-    my $prLog = shift;
-    my $tmpdir = shift;
-
-    my $prog = $main::fileTypeArchiver{$archiver}{'prog'};
-    my $opts = $main::fileTypeArchiver{$archiver}{'createOpts'}; # \@list
-    my ($pathToSourceFile, $f) = &::splitFileDir("$sourceDir/$filename");
-
-    if ($archiver eq 'tar')
-    {
-	push @$opts, '-', $f;
-	my $tar = forkProc->new('-exec' => $prog,
-				'-param' => $opts,
-				'-workingDir' => $pathToSourceFile,
-				'-stdout' => "$backupDir/$filename",
-				'-stderr' => "$tmpdir/stbuPipeArchive-",
-				'-delStdout' => 'no',
-				'-prLog' => $prLog);
-	$tar->wait();
-	my $out = $tar->getSTDOUT();
-	$prLog->print('-kind' => 'W',
-		      '-str' => ["STDOUT of <$prog @$opts>:", @$out])
-	    if (@$out > 0);
-	$out = $tar->getSTDERR();
-	$prLog->print('-kind' => 'E',
-		      '-str' => ["STDERR of <$prog @$opts>:",
-				 @$out])
-	    if (@$out > 0);
-    }
-    elsif ($archiver eq 'cpio')
-    {
-	my $cpio = pipeToFork->new('-exec' => $prog,
-				   '-param' => $opts,
-				   '-workingDir' => $pathToSourceFile,
-				   '-stdout' => "$backupDir/$filename",
-				   '-stderr' => "$tmpdir/stbuPipeArchive-",
-				   '-delStdout' => 'no',
-				   '-prLog' => $prLog);
-	$cpio->print("$f\n");
-	$cpio->wait();
-	my $out = $cpio->getSTDERR();
-	$prLog->print('-kind' => 'E',
-		      '-str' => ["STDERR of <$prog @$opts>:", @$out])
-	    if (@$out > 0);
-    }
-    else
-    {
-	$prLog->print('-kind' => 'E',
-		      '-str' => ["archiver <$archiver> unknown, exiting"],
-		      '-exit' => 1);
-    }
-}
-
-
-############################################################
-sub extractFileFromArchive
-{
-    my $filename = shift;   # relative path
-    my $restoreDir = shift;
-    my $backupDir = shift;
-    my $archiver = shift;
-    my $prLog = shift;
-    my $tmpdir = shift;
-
-#print "+++extractFileFromArchive:+$filename+$restoreDir+$backupDir+$archiver+\n";
-    my $prog = $main::fileTypeArchiver{$archiver}{'prog'};
-    my $opts = $main::fileTypeArchiver{$archiver}{'extractOpts'}; # \@list
-    my ($pathToRestoreDir, $f) = &::splitFileDir("$restoreDir/$filename");
-
-    if ($archiver eq 'tar')
-    {
-	push @$opts, "$backupDir/$filename";
-#print "+++$prog @$opts+++\n";
-	my $tar = forkProc->new('-exec' => $prog,
-				'-param' => $opts,
-				'-workingDir' => $pathToRestoreDir,
-				'-outRandom' => "$tmpdir/stbuPipeArchive-",
-				'-prLog' => $prLog);
-	$tar->wait();
-	my $out = $tar->getSTDOUT();
-	$prLog->print('-kind' => 'W',
-		      '-str' => ["STDOUT of <$prog @$opts>:", @$out])
-	    if (@$out > 0);
-	$out = $tar->getSTDERR();
-	$prLog->print('-kind' => 'E',
-		      '-str' => ["STDERR of <$prog @$opts>:", @$out])
-	    if (@$out > 0);
-    }
-    elsif ($archiver eq 'cpio')
-    {
-#print "+++$prog @$opts+++\n";
-	my $cpio = forkProc->new('-exec' => $prog,
-				 '-param' => $opts,
-				 '-workingDir' => $pathToRestoreDir,
-				 '-stdin' => "$backupDir/$filename",
-				 '-outRandom' => "$tmpdir/stbuPipeArchive-",
-				 '-prLog' => $prLog);
-	$cpio->wait();
-	my $out = $cpio->getSTDOUT();
-	$prLog->print('-kind' => 'W',
-		      '-str' => ["STDOUT of <$prog @$opts>:", @$out])
-	    if (@$out > 0);
-	$out = $cpio->getSTDERR();
-	$prLog->print('-kind' => 'E',
-		      '-str' => ["STDERR of <$prog @$opts>:", @$out])
-	    if (@$out > 0);
-    }
-    else
-    {
-	$prLog->print('-kind' => 'E',
-		      '-str' => ["archiver <$archiver> unknown, exiting"],
-		      '-exit' => 1);
-    }
-#print "+++end of extractFileFromArchive:+$filename+\n";
-}
-
-
-############################################################
-# helper functions for &main::MARK_DIR and &main::MARK_DIR_REC
-# problem is to store 2 dimensional hash with dbm files (saveRAM)
-# simulates $a{$b}{$c} = 1 or $a{$b}{$d} = 1
-# with $a{$b} = 'SEP$cSEP$aSEP' where SEPerator is \000
-sub addToStr
-{
-    my $hash = shift;
-    my $k1 = shift;
-    my $k2 = shift;
-
-    if (exists $$hash{$k1})
-    {
-	if (index($$hash{$k1}, "\000$k2\000") < 0)  # not found
-	{
-	    $$hash{$k1} = $$hash{$k1} . "$k2\000";
-	}
-    }
-    else
-    {
-	$$hash{$k1} = "\000$k2\000";
-    }
-}
-
-########################################
-sub existStr
-{
-    my $hash = shift;
-    my $k1 = shift;
-    my $k2 = shift;
-
-#    print "\thash = ", $$hash{$k1}, "\n";
-#    print "\t\t $k1 exists\n" if (exists $$hash{$k1});
-
-    if (exists $$hash{$k1} and index($$hash{$k1}, "\000$k2\000") >= 0)
-    {
-	return 1;
-    }
-    else
-    {
-	return 0;
-    }
-}
-
-
-############################################################
-# creates sparse file with specified size
-# deletes existing file
-# returns 1 if success / returns 0 if no success
-sub createSparseFile
-{
-    my $file = shift;
-    my $size = shift;
-    my $prLog = shift;
-
-    if (-e $file)
-    {
-	return 0 if unlink $file != 1;
-    }
-
-    unless (sysopen(TO, $file, O_CREAT | O_WRONLY))
-    {
-	$prLog->print('-kind' => 'E',
-		      '-str' => ["cannot create sparse file <$file>"]);
-	return 0;
-    }
-
-    sysseek(TO, $size - 1, 0);
-
-    my $buffer = pack('C', 0);
-
-    unless (syswrite(TO, $buffer))
-    {
-	$prLog->print('-kind' => 'E',
-		      '-str' =>
-		      ["cannot syswrite when creating sparse file <$file>"]);
-	return 0;
-    }
-
-    close(TO);
-    return 1;
-}
-
-
-############################################################
-# read pod2text
-sub getPod2Text
-{
-    my $file = shift;
-    my $prLog = shift;    # if not set, forkProc uses STDERR
-
-    my $p2t = forkProc->new('-exec' => 'pod2text',
-			    '-param' => [$file],
-			    '-outRandom' => "/tmp/pod2text-",
-			    '-prLog' => $prLog);
-    $p2t->wait();
-    my $out = $p2t->getSTDERR();
-    if (@$out > 0)
-    {
-	if ($prLog)
-	{
-	    $prLog->print('-kind' => 'E',
-			  '-str' => ["STDERR of <pod2text>:", @$out])
-		if (@$out > 0);
-	}
-	else
-	{
-	    print STDERR "STDERR of <pod2text>:",
-	    join("\n", @$out), "\n";
-	}
-	exit 1;
-    }
-
-    $out = $p2t->getSTDOUT();
-
-    return join("\n", grep(!/^\s*$/, @$out)) . "\n";
-}
-
-
 ############################################################
 # Objekt kann zum (wiederholten) Abfragen von Informationen
 # ber eine Datei verwendet werden.
@@ -794,8 +414,7 @@ sub new
     my ($self) = {};
 
     my (%params) = ('-filename'      => undef,
-		    '-prLog'         => undef,
-		    '-tmpdir'        => '/tmp'
+		    '-prLog'         => undef
 		    );
 
     &::checkObjectParams(\%params, \@_, 'singleFileInfo::new',
@@ -828,7 +447,6 @@ sub getInfo
 			 ['-kind']);
     my $kind = $params{'-kind'};
     my $prLog = $self->{'prLog'};
-    my $tmpdir = $self->{'tmpdir'};
 
     if ($kind eq 'md5')
     {
@@ -838,8 +456,8 @@ sub getInfo
 	}
 
 	my $f = forkProc->new('-exec' => 'md5sum',
-			      '-stdout' => "$tmpdir/out.$$",
-			      '-stderr' => "$tmpdir/err.$$",
+			      '-stdout' => "/tmp/out.$$",
+			      '-stderr' => "/tmp/err.$$",
 			      '-param' => [$self->{'filename'}],
 			      '-prLog' => $prLog);
 	$f->wait();
@@ -901,8 +519,6 @@ sub new
 		    '-followLinks'         => 0, # nicht folgen, wenn 1, dann
 		                                 # in erster Ebene folgen, mehr
 		                                 # geht bisher nicht
-		    '-stayInFileSystem'    => 0, # don't leave file system, but
-		                                 # consider --followLinks
 		    '-prLog'               => undef,
 		    '-prLogError'          => 'E',
 		    '-prLogWarn'           => 'W',
@@ -948,19 +564,6 @@ sub new
     $self->{'depths'} = \@depths;
     $self->{'printedDepth'} = -1;
 
-    my %stayInFileSystemHash;
-    $self->{'stayInFileSystemHash'} = \%stayInFileSystemHash;
-    if ($self->{'stayInFileSystem'})
-    {
-	my $dirs = $self->{'dirs'};
-	foreach my $d (@$dirs)
-	{
-	    my $device = (stat($d))[0];    # device number of filesystem
-	    $stayInFileSystemHash{$device} = $d;
-#print "(1) $device --> $d\n";
-	}
-    }
-
     bless $self, $class;
 }
 
@@ -1008,8 +611,6 @@ sub readDir
     my $except = $self->{'except'};
     my $include = $self->{'include'};
     my $includeDirs = $self->{'includeDirs'};
-    my $stayInFileSystem = $self->{'stayInFileSystem'};
-    my $stayInFileSystemHash = $self->{'stayInFileSystemHash'};
     my $ignoreReadError = $self->{'ignoreReadError'};
 
 
@@ -1081,7 +682,15 @@ sub readDir
     local *DIR;
     unless (opendir(DIR, $dir))
     {
-	if ($ignoreReadError)
+	if ($ignoreReadError eq 'no')
+	{
+	    $prLog->print('-kind' => $prLogErr,
+			  '-str' =>
+			  ["cannot opendir <$dir>, exiting",
+			   "check your source and clean your backup!"],
+			  '-exit' => $exit);
+	}
+	elsif ($ignoreReadError eq 'onlyPrintMessage')
 	{
 	    $prLog->print('-kind' => $prLogErr,
 			  '-str' => ["cannot opendir <$dir>"]);
@@ -1089,54 +698,30 @@ sub readDir
 	}
 	else
 	{
-	    $prLog->print('-kind' => $prLogErr,
-			  '-str' =>
-			  ["cannot opendir <$dir>, " .
-			   "you may want to set option ignoreReadError to " .
-			   "make this message a warning"]);
-#			  '-exit' => $exit);
 	    return;
 	}
     }
 
     my $entry;
     my @notPlainFiles;
-#########!!!!!!!!
-##my $output = undef;
-##print "reading $dir\n";
     while ($entry = readdir DIR)
     {
 	next if ($entry eq '.' or $entry eq '..');
 	$entry = $dir . '/' . $entry;
-#########!!!!!!!!
-##print "$output\n" if $output;
-##$output = $entry;
-
-#	my $mode = (stat($entry))[2];
-#	if (::S_ISLNK($mode))
 	if (-l $entry)
 	{
 	    if ($self->{'followLinks'} > $depth and
                -d "$entry/.")
 	    {
-#########!!!!!!!!
-##$output = "dir_a $output";
 		if (exists $$except{&::absolutePath($entry)})
 		{
 		    $prLog->print('-kind' => 'I',
-				  '-str' => ["ignoring directory <$entry>, " .
-				  "because of option exceptDir"])
+				  '-str' => ["ignoring directory <$entry>"])
 			if $self->{'verbose'};
 		    push @$files, $entry;
 		    push @$types, 'd';
 		    next;
 		}
-		if ($stayInFileSystem)
-		{
-		    my $device = (stat($entry))[0];
-		    $$stayInFileSystemHash{$device} = $entry;
-#print "(2) $device --> $entry\n";
-		}
 		push @$files, $entry;
 		push @$types, 'd';
 		push @$dirs, $entry;
@@ -1144,55 +729,19 @@ sub readDir
 	    }
 	    else
 	    {
-#########!!!!!!!!
-##$output = "symlink $output";
 		push @$files, $entry;
 		push @$types, 'l';
 	    }
 	    next;
 	}
 	unless (-r $entry)
-#	unless ($mode & ::S_IREAD and $> != 0)  # $> -> effective user id
 	{
-	    next
-		if exists $$except{&::absolutePath($entry)};
-
-	    if ($ignoreReadError)
-	    {
-		$prLog->print('-kind' => $prLogWarn,
-			      '-str' => ["no permissions to read <$entry>"]);
-	    }
-	    else
-	    {
-		$prLog->print('-kind' => $prLogErr,
-			      '-str' => ["no permissions to read <$entry>, " .
-			      "you may want to set option ignoreReadError to " .
-			      "make this message a warning"]);
-#			      '-exit' => 1);
-	    }
+	    $prLog->print('-kind' => $prLogWarn,
+			  '-str' => ["no permissions to read <$entry>"]);
 	    next;
 	}
 	if (-d $entry)       # Dieses Directory mu beim Kopieren
-#	if (::S_ISDIR($mode))  # Dieses Directory mu beim Kopieren
 	{                      # z.B. mu angelegt werden!
-#########!!!!!!!!
-##$output = "dir $output";
-	    if ($stayInFileSystem)
-	    {
-		my $device = (stat($entry))[0];
-		if (not exists $$stayInFileSystemHash{$device})
-		{
-		    $prLog->print('-kind' => 'I',
-				  '-str' => ["ignoring directory <$entry>, " .
-				  "because of option stayInFileSystem"])
-			if $self->{'verbose'};
-		    push @$files, $entry;
-		    push @$types, 'd';
-#print "(3) nix $device --> $entry\n";
-		    next;
-		}
-#print "(2) $device --> $entry\n";
-	    }
 	    push @$files, $entry;
 	    push @$types, 'd';
 	    next if exists $$except{&::absolutePath($entry)};
@@ -1201,46 +750,31 @@ sub readDir
 	    next;
 	}
 	if (-f $entry)
-#	if (::S_ISREG($mode))
 	{
-#########!!!!!!!!
-##$output = "file $output";
 	    push @$files, $entry;
 	    push @$types, 'f';
 	    next;
 	}
 	if (-p $entry)      # named pipe
-#	if (::S_ISFIFO($mode))      # named pipe
 	{
-#########!!!!!!!!
-##$output = "pipe $output";
 	    push @$files, $entry;
 	    push @$types, 'p';
 	    next;
 	}
 	if (-S $entry)      # socket
-#	if (::S_ISSOCK($mode))      # socket
 	{
-#########!!!!!!!!
-##$output = "socket $output";
 	    push @$files, $entry;
 	    push @$types, 'S';
 	    next;
 	}
 	if (-b $entry)      # block special file
-#	if (::S_ISBLK($mode))      # block special file
 	{
-#########!!!!!!!!
-##$output = "blockSpecial $output";
 	    push @$files, $entry;
 	    push @$types, 'b';
 	    next;
 	}
 	if (-c $entry)      # character special file
-#	if (::S_ISCHR($mode))      # character special file
 	{
-#########!!!!!!!!
-##$output = "charSpecial $output";
 	    push @$files, $entry;
 	    push @$types, 'c';
 	    next;
@@ -1249,9 +783,6 @@ sub readDir
 		      '-str' => ["unsupported file type for <$entry>"]);
     }
 
-#########!!!!!!!!
-##print "$output\n" if $output;
-
     closedir DIR;
 }
 
