@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 #
-#   Copyright (C) Heinz-Josef Claes (2009-2020)
+#   Copyright (C) Heinz-Josef Claes (2009)
 #                 hjclaes@web.de
 #
 #   This program is free software: you can redistribute it and/or modify
@@ -18,6 +18,8 @@
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+# '$Id $ ';
+
 use Fcntl;
 use Digest::MD5 qw(md5_hex);
 
@@ -35,32 +37,29 @@ my ($fileToRead, $fileToSave, $md5RetFile) = @ARGV;
 
 unless (sysopen(IN, $fileToRead, O_RDONLY))
 {
-    print STDERR "cannot open <$fileToRead> (", __FILE__, " ", __LINE__,  ")\n";
+    print STDERR "cannot open <$fileToRead>\n";
     exit 1;
 }
 
 unless (sysopen(OUT, $fileToSave, O_CREAT|O_WRONLY, 0700))
 {
-    print STDERR "cannot open <$fileToSave> (", __FILE__, " ", __LINE__,  ")\n";
+    print STDERR "cannot open <$fileToSave>\n";
     exit 2;
 }
 
 my $md5 = Digest::MD5->new();
-my ($buffer, $n, $size);
-$size = 0;
-while ($n = sysread(IN, $buffer, 4096))
+my $buffer;
+while (sysread(IN, $buffer, 4096))
 {
-    print STDERR "cannot write to <$fileToSave>\n"
-	unless syswrite OUT, $buffer;
+    syswrite OUT, $buffer;
     $md5->add($buffer);
-    $size += $n;
 }
 close(OUT);
 close(IN);
 
 open(MD5, '>', $md5RetFile)
     or exit 3;
-print MD5 $md5->hexdigest(), "\n$size\n";
+print MD5 $md5->hexdigest(), "\n";
 close(MD5);
 
 exit 0;
